==> qtjambi-positioning-debuginfo-linux-x64-6.5.5.jar: sources/QtJambiPositioning/QGeoPositionInfoSource_shell.h <==
#ifndef QGEOPOSITIONINFOSOURCE_SHELL_H
#define QGEOPOSITIONINFOSOURCE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtPositioning/qgeopositioninfosource.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtPositioning/qgeopositioninfo.h>
#include <QtJambi/RegistryAPI>


class QGeoPositionInfoSource_shell : public QGeoPositionInfoSource, public QtJambiShellInterface
{
public:
    QGeoPositionInfoSource_shell(QObject* parent0);
    ~QGeoPositionInfoSource_shell() override;

    QVariant backendProperty(const QString& name0) const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    QGeoPositionInfoSource::Error error() const override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QGeoPositionInfo lastKnownPosition(bool fromSatellitePositioningMethodsOnly0) const override;
    int minimumUpdateInterval() const override;
    void requestUpdate(int timeout0) override;
    bool setBackendProperty(const QString& name0, const QVariant& value1) override;
    void setPreferredPositioningMethods(QGeoPositionInfoSource::PositioningMethods methods0) override;
    void setUpdateInterval(int msec0) override;
    void startUpdates() override;
    void stopUpdates() override;
    QGeoPositionInfoSource::PositioningMethods supportedPositioningMethods() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QGeoPositionInfoSource_access : public QGeoPositionInfoSource
{
    jobject __qt_backendProperty_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0) const;
    jint __qt_error_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_lastKnownPosition_bool_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean fromSatellitePositioningMethodsOnly0) const;
    jint __qt_minimumUpdateInterval_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_requestUpdate_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint timeout0);
    jboolean __qt_setBackendProperty_cref_QString_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0, jobject value1);
    void __qt_setPreferredPositioningMethods_QGeoPositionInfoSource_PositioningMethods(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint methods0);
    void __qt_setUpdateInterval_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint msec0);
    void __qt_startUpdates(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_stopUpdates(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jint __qt_supportedPositioningMethods_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QGEOPOSITIONINFOSOURCE_SHELL_H

==> qtjambi-positioning-debuginfo-linux-x64-6.6.1.jar: sources/QtJambiPositioning/QGeoPositionInfoSource_shell.h <==
#ifndef QGEOPOSITIONINFOSOURCE_SHELL_H
#define QGEOPOSITIONINFOSOURCE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtPositioning/qgeopositioninfosource.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtPositioning/qgeopositioninfo.h>
#include <QtJambi/RegistryAPI>


class QGeoPositionInfoSource_shell : public QGeoPositionInfoSource, public QtJambiShellInterface
{
public:
    QGeoPositionInfoSource_shell(QObject* parent0);
    ~QGeoPositionInfoSource_shell() override;

    QVariant backendProperty(const QString& name0) const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    QGeoPositionInfoSource::Error error() const override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QGeoPositionInfo lastKnownPosition(bool fromSatellitePositioningMethodsOnly0) const override;
    int minimumUpdateInterval() const override;
    void requestUpdate(int timeout0) override;
    bool setBackendProperty(const QString& name0, const QVariant& value1) override;
    void setPreferredPositioningMethods(QGeoPositionInfoSource::PositioningMethods methods0) override;
    void setUpdateInterval(int msec0) override;
    void startUpdates() override;
    void stopUpdates() override;
    QGeoPositionInfoSource::PositioningMethods supportedPositioningMethods() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QGeoPositionInfoSource_access : public QGeoPositionInfoSource
{
    jobject __qt_backendProperty_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0) const;
    jint __qt_error(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_lastKnownPosition_bool_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean fromSatellitePositioningMethodsOnly0) const;
    jint __qt_minimumUpdateInterval(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_requestUpdate_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint timeout0);
    jboolean __qt_setBackendProperty_cref_QString_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring name0, jobject value1);
    void __qt_setPreferredPositioningMethods_QGeoPositionInfoSource_PositioningMethods(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint methods0);
    void __qt_setUpdateInterval_int(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint msec0);
    void __qt_startUpdates(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_stopUpdates(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jint __qt_supportedPositioningMethods(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QGEOPOSITIONINFOSOURCE_SHELL_H
